Documentation
¶
Overview ¶
Package generate has the logic to generate Graph from HCL or State
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromHCL ¶
FromHCL generates a new graph from the HCL on the path, it can be a file or a Module/Dir
func ValidateTFStateVersion ¶ added in v0.6.7
ValidateTFStateVersion validates that the version is the one we support which is only 3 and 4
Types ¶
type Options ¶
type Options struct {
// Raw means the RawProvider instead of the
// specific one
Raw bool
// Clean means that the Nodes that do not have
// any connection will be "removed"
Clean bool
// Connections toggles the Provider logic for
// merging Edges between Nodes into one
Connections bool
// ExternalNodes will try to add extra
// Nodes detected to make the graph better,
// like the 'im_out'
ExternalNodes bool
}
Options are the possible options that can be used to generate a Graph
Click to show internal directories.
Click to hide internal directories.